import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Input, Select, Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {DescItem} from "@/components/Description";
import {uploadApi} from "@/api/sys/upload"; // 引入开关组件
type CheckedType = boolean | string | number;

/**首页-table列表1*/
export const columns: BasicColumn[] = [
  {
    title: '调度时间',
    dataIndex: 'schedulingTime',
    width: 120
  },
  {
    title: '执行时间',
    dataIndex: 'executionTime',
    width: 120
  },
  {
    title: '执行时长',
    dataIndex: 'executionDuration',
    width: 120
  },
  {
    title: '运行状态',
    dataIndex: 'runningStatus',
    width: 120
  },
  {
    title: '执行条件',
    dataIndex: 'executionCondition',
    width: 120,
    slots: {customRender: 'executionCondition'}
  },
  {
    title: '执行模式',
    dataIndex: 'executionMode',
    width: 120
  },
  {
    title: '执行版本',
    dataIndex: 'executionVersion',
    width: 120
  },
  {
    title: '执行信息',
    dataIndex: 'executionInfo',
    width: 120
  },
  {
    title: '执行ID',
    dataIndex: 'executionId',
    width: 120
  }
];
/**首页-table列表2*/
export const columns2: BasicColumn[] = [
  {
    title: '条件类型',
    dataIndex: 'conditionType',
    width: 120
  },
  {
    title: '详情',
    dataIndex: 'detail',
    width: 120
  },
  {
    title: '是否满足',
    dataIndex: 'satisfy',
    width: 120
  },
];
/**首页-搜索表单*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'taskName',
    label: '',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关键字搜索',
      },
    ],
    componentProps: {
      placeholder: '请输入关键字搜索',
    }
  },
];
/**首页-表单1*/
export const topFormSchema1: FormSchema[] = [
  {
    field: 'tree',
    label: '',
    component: 'TreeSelect',
    colProps: { span: 10 },
    componentProps: {
      maxTagCount:1,//最大tag数量
      showArrow: true,//箭头
      treeCheckable: true,
      fieldNames: {
        label: 'treeName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
];
/**首页-表单2*/
export const topFormSchema2: FormSchema[] = [
  {
    field: 'agreement',
    component: 'RadioButtonGroup',
    label: '',
    defaultValue: '1',
      componentProps: {
      options: [
        {
          label: '调度时间',
          value: '1',
        },
        {
          label: '执行时间',
          value: '2',
        },
      ],
    },
  },
  {
    field: '[startDate, endDate]',
    label: ' ',
    labelWidth:20,
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      placeholder: ['开始日期', '结束日期'],
    },
  },
  {
    field: 'eventType',
    label: ' ',
    labelWidth:20,
    component: 'Select',
    componentProps: {
      placeholder: '类型',
      options: [
        {
          label: '调度',
          value: '全部',
        },
      ],
    },
  },
];
/**首页-表单3*/
export const mainFormSchema3: FormSchema[] = [
  {
    field: 'schedulingCycle',
    label: '调度周期',
    component: 'Input',
    defaultValue: '0 0 0 ? * * *',
    labelWidth:120,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入调度周期',
    },
    colProps: { lg: 5, md: 24 },
  },
  {
    field: 'publishState',
    label: '发布状态',
    component: 'Input',
    defaultValue: '已发布',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入发布状态',
    },
    colProps: { lg: 5, md: 24 },
  },
  {
    field: 'approvalState',
    label: '审批状态',
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入审批状态',
    },
    colProps: { lg: 5, md: 24 },
  },
  {
    field: 'uuid',
    label: '任务流UUID',
    component: 'Input',
    defaultValue: '4467f504c263466db3b752dc97d51d42',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入任务流UUID',
    },
    colProps: { lg: 8, md: 24 },
  },
];
/**首页-表单4*/
export const mainFormSchema4: FormSchema[] = [
  {
    field: 'settingTask',
    label: '',
    component: 'RadioGroup',
    defaultValue: '自动触发下游',
    componentProps: {
      options: [
        { label: '仅当前任务', value: '仅当前任务' },
        { label: '自动触发下游', value: '自动触发下游' },
      ],
    },
  },
];
/**重跑 表单*/
export const runAgainSchema1: FormSchema[] = [
  {
    field: 'scopeAction',
    label: '作用范围',
    component: 'RadioGroup',
    defaultValue: '当前任务流',
    componentProps: {
      options: [
        { label: '当前任务流', value: '当前任务流' },
        { label: '当前及其下游', value: '当前及其下游' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'operationPriority',
    label: '操作优先级',
    component: 'RadioGroup',
    defaultValue: '高',
    componentProps: {
      options: [
        { label: '高', value: '高' },
        { label: '中', value: '中' },
        { label: '低', value: '低' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field:'slot',
    label:'',
    component:'',
    slot:'slot'
  }
];
/**重跑 表单*/
export const runAgainSchema2: FormSchema[] = [
  {
    field: 'scopeAction',
    label: '作用范围',
    component: 'RadioGroup',
    defaultValue: '当前任务',
    componentProps: {
      options: [
        { label: '当前任务', value: '当前任务' },
        { label: '当前及其下游', value: '当前及其下游' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field:'slot',
    label:'',
    component:'',
    slot:'slot'
  }
];
/**详情页-任务列表*/
export const tableListColumns: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'taskName',
    width: 120
  },
  {
    title: '运行状态',
    dataIndex: 'runStatus',
    width: 120,
    slots: { customRender: 'runStatus' },
  },
  {
    title: '执行条件',
    dataIndex: 'executionCondition',
    width: 120,
    slots: { customRender: 'executionCondition' },
  },
  {
    title: '运行开始时间',
    dataIndex: 'startTime',
    width: 120
  },
  {
    title: '运行结束时间',
    dataIndex: 'endTime',
    width: 120
  },
  {
    title: '运行时长',
    dataIndex: 'duration',
    width: 120
  },
  {
    title: '执行版本',
    dataIndex: 'executionVersion',
    width: 120
  },
  {
    title: '执行ID',
    dataIndex: 'executionId',
    width: 120
  }
];
/**详情页-表单*/
export const detailFormSchema: FormSchema[] = [
  {
    field: 'agreement',
    component: 'RadioButtonGroup',
    label: '',
    defaultValue: '1',
    componentProps: {
      options: [
        {
          label: '调度时间',
          value: '1',
        },
        {
          label: '执行时间',
          value: '2',
        },
      ],
    },
  },
  {
    field: '[startDate, endDate]',
    label: ' ',
    labelWidth:20,
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      placeholder: ['开始日期', '结束日期'],
    },
  },
  {
    field: 'eventType',
    label: ' ',
    labelWidth:20,
    component: 'Select',
    componentProps: {
      placeholder: '类型',
      options: [
        {
          label: '调度',
          value: '全部',
        },
      ],
    },
  },
  {
    field: 'switch',
    component: '',
    label: '展示切换',
    slot: 'switch'
  },
];
/**详情页-依赖列表1*/
export const dependencyRelationshipColumns1: BasicColumn[] = [
  {
    title: '执行ID',
    dataIndex: 'executeId',
    width: 100
  },
  {
    title: '时间信息',
    dataIndex: 'timeInfo',
    width: 200,
    slots: { customRender: 'timeInfo' },
  },
  {
    title: '运行状态',
    dataIndex: 'runState',
    width: 100,
    slots: { customRender: 'runState' },
  },
  {
    title: '执行模式',
    dataIndex: 'executeMode',
    width: 100
  },
];
/**详情页-依赖列表2*/
export const dependencyRelationshipColumns2: BasicColumn[] = [
  {
    title: '执行ID',
    dataIndex: 'executeId',
    width: 100
  },
  {
    title: '时间信息',
    dataIndex: 'timeInfo',
    width: 200,
    slots: { customRender: 'timeInfo' },
  },
  {
    title: '运行状态',
    dataIndex: 'runState',
    width: 100,
    slots: { customRender: 'runState' },
  },
];
