import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Input, Select, Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {DescItem} from "@/components/Description";
import {uploadApi} from "@/api/sys/upload"; // 引入开关组件
type CheckedType = boolean | string | number;

/**首页-table列表*/
export const columns: BasicColumn[] = [
  {
    title: '补数名称',
    dataIndex: 'supplyNumberName',
    width: 120,
    slots: { customRender: 'supplyNumberName' },
  },
  {
    title: '创建者',
    dataIndex: 'createBy',
    width: 120
  },
  {
    title: '补数状态',
    dataIndex: 'supplyNumberState',
    width: 120
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 120
  },
  {
    title: '完成时间',
    dataIndex: 'completionTime',
    width: 120
  },
  {
    title: '补数日期',
    dataIndex: 'supplyNumberTime',
    width: 120
  },
];
/**首页-搜索表单*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'supplyNumberName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '请输入关键字搜索',
    },
  },
  {
    field: 'createTime',
    label: '创建时间',
    component: 'DatePicker',
    componentProps: {
      placeholder: '请选择创建时间',
    },
  },
  {
    field: 'supplyState',
    label: '补数状态',
    component: 'Select',
    componentProps: {
      placeholder: '请选择补数状态',
      options: [
        {
          label: '已取消',
          value: '已取消',
        },
        {
          label: '已完成',
          value: '已完成',
        },
      ],
    },
  },

];
/**首页-下拉框表单*/
export const selectFormSchema: FormSchema[] = [
  {
    field: 'tree',
    label: '',
    component: 'TreeSelect',
    colProps: { span: 3 },
    componentProps: {
      maxTagCount:1,//最大tag数量
      showArrow: true,//箭头
      treeCheckable: true,
      fieldNames: {
        label: 'treeName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
];
/**新建任务页-表单1*/
export const addTaskFormSchema1: FormSchema[] = [
  {
    field: 'supplyNumberName',
    label: '补数名称',
    labelWidth:80,
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入补数名称',
    },
    colProps: {lg: 12, md: 24}
  },
  {
    field: 'rangeTime',
    label: ' 补数时间范围',
    labelWidth:120,
    component: 'RangePicker',
    required: true,
    componentProps: {
      placeholder: ['开始时间', '结束时间'],
    },
    colProps: {lg: 12, md: 24}
  },
];
/**新建任务页-表单2*/
export const addTaskFormSchema2: FormSchema[] = [
  {
    field: 'taskStreamName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '任务流名称搜索',
    },
  },
];
/**新建任务页-表单3*/
export const addTaskFormSchema3: FormSchema[] = [
  {
    field: 'taskStreamName',
    label: ' ',
    labelWidth:10,
    component: 'Input',
    componentProps: {
      placeholder: '任务流名称搜索',
    },
  },
  {
    field: 'taskStream',
    label: ' ',
    labelWidth:20,
    component: 'Select',
    componentProps: {
      placeholder: '手动选择的任务流',
      options: [
        {
          label: 'QC12345',
          value: '1',
        },
        {
          label: 'Smart financial modeling',
          value: '2',
        },
        {
          label: 'Result data entry',
          value: '3',
        },
        {
          label: 'Shed and huo area',
          value: '4',
        },
      ],
    },
  },
  {
    field: 'publishState',
    label: ' ',
    labelWidth:20,
    component: 'Select',
    componentProps: {
      placeholder: '发布状态',
      options: [
        {
          label: '已发布',
          value: '已发布',
        },
        {
          label: '未发布',
          value: '未发布',
        },
      ],
    },
  },
];
/**新建任务页-表单4*/
export const addTaskFormSchema4: FormSchema[] = [
  {
    field: 'taskStreamName',
    label: '任务流名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入任务流名称',
    },
    rules: [
      {
        required: true,
        message: '请输入任务流名称',
      },
    ],
    colProps: {lg: 24}
  },
  {
    field: 'taskStreamLocation',
    label: '任务流位置',
    component: 'Input',
    componentProps: {
      placeholder: '请输入任务流位置',
    },
    rules: [
      {
        required: true,
        message: '请输入任务流位置',
      },
    ],
    colProps: {lg: 24}
  },
];
/**新建任务页-table列表1*/
export const addTaskColumns1: BasicColumn[] = [
  {
    title: '任务流名称',
    dataIndex: 'taskStreamName',
    width: 120,
    slots:{customRender:'taskStreamName'}
  },
  {
    title: '任务流位置',
    dataIndex: 'taskStreamLocation',
    width: 120,
  },
];
/**新建任务页-table列表2*/
export const addTaskColumns2: BasicColumn[] = [
  {
    title: '补数范围内任务流',
    dataIndex: 'rangeTaskStream',
    width: 120,
    slots: { customRender: 'rangeTaskStream' },
  },
  {
    title: '发布状态',
    dataIndex: 'publishState',
    width: 120,
    slots: { customRender: 'publishState' },
  },
  {
    title: '手动选择的任务流',
    dataIndex: 'chooseTaskStream',
    width: 120,
    slots: { customRender: 'chooseTaskStream' },
  },
];
